@@ -89,9 +89,9 @@ class ArgumentConversion:
                 self.unknownArg = p
 
     def convert(self, req: flask.Request, ce: ce_sdk.BaseEvent = None) -> typing.Any:
-        if not self.convertable:
+        if not self.valid:
             raise ValueError(f"Unable to convert {self.p} to a function argument.")
-        if self._need_event:
+        if self.need_event:
             return self._convert(ce)
         return self._convert(req)
 
